pub struct ClientAuthData {
pub private_key: DataEncoding,
pub cert_chain: DataEncoding,
}Expand description
Raw private key and certificate data to facilitate client authentication.
Fields
private_key: DataEncodingprivate key used by client
cert_chain: DataEncodingcertificate chain as a companion to the private key