pub struct ClientConfig {
pub cipher_suites: Option<Vec<CipherSuite>>,
pub compression_algorithms: Option<Vec<CompressionAlgorithm>>,
pub extensions: Option<Vec<ClientHelloExtension>>,
pub server_verify_mode: Option<ServerVerifyMode>,
pub client_auth: Option<ClientAuth>,
pub key_logger: Option<KeyLogIntent>,
pub store_server_certificate_chain: bool,
}Expand description
Common API to configure a TLS Client
Fields
cipher_suites: Option<Vec<CipherSuite>>optional intent for cipher suites to be used by client
compression_algorithms: Option<Vec<CompressionAlgorithm>>optional intent for compression algorithms to be used by client
extensions: Option<Vec<ClientHelloExtension>>optional intent for extensions to be used by client
Commpon examples are:
server_verify_mode: Option<ServerVerifyMode>optionally define how server should be verified by client
client_auth: Option<ClientAuth>optionally define raw (PEM-encoded) client auth certs
key_logger: Option<KeyLogIntent>key log intent
store_server_certificate_chain: boolif enabled server certificates will be stored in [NegotiatedTlsParameters]
Implementations
Sourceimpl ClientConfig
impl ClientConfig
Sourcepub fn merge(&mut self, other: ClientConfig)
pub fn merge(&mut self, other: ClientConfig)
Merge this ClientConfig with aother one.